@@ -26,7 +26,7 @@
 
 
 GtkWidget   *mFile, *mTools, *mMeta, *mArea;
-GtkWidget   *mEdit, *mRep, *mColor, *mBend, *mEff, *mComb;
+GtkWidget   *mEdit, *mRep, *mBend, *mEff, *mComb;
 GtkWidget   *mPlug, *mHelp;
 GtkWidget   *mToolsG;                                                      //  v.14.07
 
@@ -69,21 +69,21 @@ void build_widgets()
    Fpanlab = gtk_label_new("panel"); 
    gtk_widget_override_font(Fpanlab,panelfont);
    gtk_box_pack_start(GTK_BOX(Fpanel),Fpanlab,0,0,0);
-   Fdraw = gtk_drawing_area_new();                                         //  image drawing area
-   gtk_widget_override_background_color(Fdraw,gtksf,&GDKdark); 
-   gtk_box_pack_start(GTK_BOX(Fvbox),Fdraw,1,1,0);
+   Fdrawin = gtk_drawing_area_new();                                       //  image drawing area
+   gtk_widget_override_background_color(Fdrawin,gtksf,&GDKbackground); 
+   gtk_box_pack_start(GTK_BOX(Fvbox),Fdrawin,1,1,0);
    gtk_widget_hide(Fhbox);
 
-   gtk_widget_add_events(Fdraw,GDK_BUTTON_PRESS_MASK);                     //  connect mouse events to image window
-   gtk_widget_add_events(Fdraw,GDK_BUTTON_RELEASE_MASK);
-   gtk_widget_add_events(Fdraw,GDK_BUTTON_MOTION_MASK);
-   gtk_widget_add_events(Fdraw,GDK_POINTER_MOTION_MASK);
-   gtk_widget_add_events(Fdraw,GDK_SCROLL_MASK);
-   G_SIGNAL(Fdraw,"button-press-event",mouse_event,0);                     //  connect signals
-   G_SIGNAL(Fdraw,"button-release-event",mouse_event,0);
-   G_SIGNAL(Fdraw,"motion-notify-event",mouse_event,0);
-   G_SIGNAL(Fdraw,"scroll-event",mouse_event,0);
-   G_SIGNAL(Fdraw,"draw",FWpaint,0);
+   gtk_widget_add_events(Fdrawin,GDK_BUTTON_PRESS_MASK);                   //  connect mouse events to image window
+   gtk_widget_add_events(Fdrawin,GDK_BUTTON_RELEASE_MASK);
+   gtk_widget_add_events(Fdrawin,GDK_BUTTON_MOTION_MASK);
+   gtk_widget_add_events(Fdrawin,GDK_POINTER_MOTION_MASK);
+   gtk_widget_add_events(Fdrawin,GDK_SCROLL_MASK);
+   G_SIGNAL(Fdrawin,"button-press-event",mouse_event,0);                   //  connect signals
+   G_SIGNAL(Fdrawin,"button-release-event",mouse_event,0);
+   G_SIGNAL(Fdrawin,"motion-notify-event",mouse_event,0);
+   G_SIGNAL(Fdrawin,"scroll-event",mouse_event,0);
+   G_SIGNAL(Fdrawin,"draw",Fpaint,0);
 
    //  G view widgets - thumbnail gallery
 
@@ -106,17 +106,20 @@ void build_widgets()
    gtk_scrolled_window_set_policy(SCROLLWIN(Gscroll),NEVER,ALWAYS);
    Gadjust = gtk_scrolled_window_get_vadjustment(SCROLLWIN(Gscroll));
    gtk_box_pack_start(GTK_BOX(Gvbox),Gscroll,1,1,0);
-   Gdraw = gtk_drawing_area_new();                                         //  gallery drawing area
-   gtk_container_add(GTK_CONTAINER(Gscroll),Gdraw);
+   Gdrawin = gtk_drawing_area_new();                                       //  gallery drawing area
+   gtk_container_add(GTK_CONTAINER(Gscroll),Gdrawin);
    gtk_widget_hide(Ghbox);
 
-   gtk_widget_add_events(Gdraw,GDK_BUTTON_PRESS_MASK);                     //  connect mouse events to gallery window
-   gtk_widget_add_events(Gdraw,GDK_BUTTON_RELEASE_MASK);
    gtk_widget_add_events(Gpath,GDK_BUTTON_PRESS_MASK);
+   gtk_widget_add_events(Gdrawin,GDK_BUTTON_PRESS_MASK);                   //  connect mouse events to gallery window
+   gtk_widget_add_events(Gdrawin,GDK_BUTTON_RELEASE_MASK);
+   gtk_widget_add_events(Gdrawin,GDK_POINTER_MOTION_MASK);
    G_SIGNAL(Gpath,"button-press-event",navi::changedirk,0);                //  connect signals
    G_SIGNAL(Gtop,"clicked",navi::newtop,0);
-   G_SIGNAL(Gdraw,"button-release-event",navi::mouse_event,0);
-   G_SIGNAL(Gdraw,"draw",navi::gallery_paint,0);
+   G_SIGNAL(Gdrawin,"button-press-event",navi::mouse_event,0);             //  v.14.08
+   G_SIGNAL(Gdrawin,"button-release-event",navi::mouse_event,0);
+   G_SIGNAL(Gdrawin,"motion-notify-event",navi::mouse_event,0);            //  v.14.08
+   G_SIGNAL(Gdrawin,"draw",navi::gallery_paint,0);
 
    //  W view widgets - world map
 
@@ -126,23 +129,22 @@ void build_widgets()
    gtk_box_pack_start(GTK_BOX(Whbox),Wmenu,0,0,0);
    Wvbox = gtk_box_new(VERTICAL,0);                                        //  right vbox for world map
    gtk_box_pack_start(GTK_BOX(Whbox),Wvbox,1,1,0);
-   Wdraw = gtk_drawing_area_new();                                         //  world map drawing area
-   gtk_widget_override_background_color(Wdraw,gtksf,&GDKdark); 
-   gtk_box_pack_start(GTK_BOX(Wvbox),Wdraw,1,1,0);
+   Wdrawin = gtk_drawing_area_new();                                       //  world map drawing area
+   gtk_widget_override_background_color(Wdrawin,gtksf,&GDKbackground); 
+   gtk_box_pack_start(GTK_BOX(Wvbox),Wdrawin,1,1,0);
    gtk_widget_hide(Whbox);
 
-   gtk_widget_add_events(Wdraw,GDK_BUTTON_PRESS_MASK);                     //  connect mouse events to world map window
-   gtk_widget_add_events(Wdraw,GDK_BUTTON_RELEASE_MASK);
-   gtk_widget_add_events(Wdraw,GDK_BUTTON_MOTION_MASK);
-   gtk_widget_add_events(Wdraw,GDK_POINTER_MOTION_MASK);
-   gtk_widget_add_events(Wdraw,GDK_SCROLL_MASK);
-   G_SIGNAL(Wdraw,"button-press-event",mouse_event,0);                     //  connect signals
-   G_SIGNAL(Wdraw,"button-release-event",mouse_event,0);
-   G_SIGNAL(Wdraw,"motion-notify-event",mouse_event,0);
-   G_SIGNAL(Wdraw,"scroll-event",mouse_event,0);
-   G_SIGNAL(Wdraw,"draw",FWpaint,0);
+   gtk_widget_add_events(Wdrawin,GDK_BUTTON_PRESS_MASK);                   //  connect mouse events to world map window
+   gtk_widget_add_events(Wdrawin,GDK_BUTTON_RELEASE_MASK);
+   gtk_widget_add_events(Wdrawin,GDK_BUTTON_MOTION_MASK);
+   gtk_widget_add_events(Wdrawin,GDK_POINTER_MOTION_MASK);
+   gtk_widget_add_events(Wdrawin,GDK_SCROLL_MASK);
+   G_SIGNAL(Wdrawin,"button-press-event",mouse_event,0);                   //  connect signals
+   G_SIGNAL(Wdrawin,"button-release-event",mouse_event,0);
+   G_SIGNAL(Wdrawin,"motion-notify-event",mouse_event,0);                  //  v.14.08
+   G_SIGNAL(Wdrawin,"scroll-event",mouse_event,0);
+   G_SIGNAL(Wdrawin,"draw",Fpaint,0);
    
-
    //  prepare menus for F/G/W view modes
 
    int      me, ii, err;
@@ -166,7 +168,6 @@ void build_widgets()
    mArea = create_popmenu();
    mEdit = create_popmenu();                                               //  v.14.07
    mRep = create_popmenu();
-   mColor = create_popmenu();
    mBend = create_popmenu();
    mEff = create_popmenu();
    mComb = create_popmenu();
@@ -177,20 +178,19 @@ void build_widgets()
    cchar * gallery_tip = ZTX("Thumbnail Gallery");
    cchar * worldmap_tip = ZTX("World Map");
    cchar * favorites_tip = ZTX("Favorite Functions");
-   cchar * file_tip = ZTX("File: Open, Save, Trash, Rename, Print");
+   cchar * file_tip = ZTX("File: Sync, Open, Save, Trash, Rename, Print");
    cchar * tools_tip = ZTX("Tools: Index, Settings, Collections, Batch Funcs ...");
    cchar * metadata_tip = ZTX("Metadata: Captions, Tags, Ratings, Geotags, Search ... ");
    cchar * areas_tip = ZTX("Areas: Select areas to edit, copy and paste");
-   cchar * edit_tip = ZTX("Edit: Trim, Rotate, Resize, Brightness, Color, Text ...");
-   cchar * repair_tip = ZTX("Repair: Sharpen, Clean, Red-eyes, Paint, Clone ...");
-   cchar * color_tip = ZTX("Color: White Balance, Color Profile, Color Matching");
+   cchar * edit_tip = ZTX("Edit: Trim, Rotate, Resize, Brightness, Contrast, Text ...");
+   cchar * repair_tip = ZTX("Repair: Sharpen, Noise, Red-eyes, Color, Paint, Clone ...");
    cchar * bend_tip = ZTX("Bend: Fix Perspective, Bend/Warp image ...");
    cchar * effects_tip = ZTX("Effects: Special Effects, Arty Transforms");
    cchar * combine_tip = ZTX("Combine: HDR, HDF, Panorama, Stack, Mashup");
    cchar * plugins_tip = ZTX("Plugins: Use other image editors within Fotoxx");
    cchar * help_tip = ZTX("Help: Quick Start, User Guide, Recent Changes ...");
-   cchar * undo_redo_tip = ZTX("Undo or Redo one edit");
-   cchar * prev_next_tip = ZTX("Open previous or next file");
+   cchar * undo_redo_tip = ZTX("Undo or Redo one edit (left/right mouse click) \n hold key A to include all edits");
+   cchar * prev_next_tip = ZTX("Open previous or next file (left/right mouse click)");
    cchar * save_tip = ZTX("Save modified image file to disk");
    cchar * sync_G_tip = ZTX("Set gallery from current image file");
 
@@ -203,7 +203,6 @@ void build_widgets()
    MENUENT(0,  ZTX("Areas"),        "areas.png",      areas_tip,        (cbFunc *) popup_menu,  (cchar *) mArea);
    MENUENT(0,  ZTX("Edit"),         "edit.png",       edit_tip,         (cbFunc *) popup_menu,  (cchar *) mEdit);
    MENUENT(0,  ZTX("Repair"),       "repair.png",     repair_tip,       (cbFunc *) popup_menu,  (cchar *) mRep);
-   MENUENT(0,  ZTX("Color"),        "color.png",      color_tip,        (cbFunc *) popup_menu,  (cchar *) mColor);
    MENUENT(0,  ZTX("Bend"),         "bend.png",       bend_tip,         (cbFunc *) popup_menu,  (cchar *) mBend);
    MENUENT(0,  ZTX("Effects"),      "effects.png",    effects_tip,      (cbFunc *) popup_menu,  (cchar *) mEff);
    MENUENT(0,  ZTX("Combine"),      "combine.png",    combine_tip,      (cbFunc *) popup_menu,  (cchar *) mComb);
@@ -213,7 +212,7 @@ void build_widgets()
    MENUENT(0,  ZTX("Prev/Next"),    "prev_next.png",  prev_next_tip,    m_prev_next, 0 );
    MENUENT(0,  ZTX("Save"),         "save.png",       save_tip,         m_file_save, 0 );
 
-   MENUENT(0,  ZTX("Undo"),         "KB shortcut",    0,                m_undo, 0 );               //  KB shortcut only
+   MENUENT(0,  ZTX("Undo"),         "KB shortcut",    0,                m_undo, 0 );               //  KB shortcut only  v.14.07.1
    MENUENT(0,  ZTX("Redo"),         "KB shortcut",    0,                m_redo, 0 );               //  KB shortcut only
 
    MENUENT(mFile,    ZTX("Sync Gallery"), 0,                   sync_G_tip,                               navi::menufuncx, 0 );
@@ -232,37 +231,38 @@ void build_widgets()
    MENUENT(mFile,    ZTX("Print Image"), 0,                    ZTX("Print the current image"),           m_print, 0 );
    MENUENT(mFile,    ZTX("Quit Fotoxx"), 0,                    ZTX("Quit Fotoxx"),                       m_quit, 0 );
 
-   MENUENT(mTools,   ZTX("Index Image Files"), 0,           ZTX("Index new files and make thumbnails"),         m_index, 0 );
-   MENUENT(mTools,   ZTX("User Settings"), 0,               ZTX("Change user preferences"),                     m_settings, 0 );
-   MENUENT(mTools,   ZTX("Keyboard Shortcuts"), 0,          ZTX("Change Keyboard Shortcut Keys"),               m_KBshortcuts, 0 );
-   MENUENT(mTools,   ZTX("Manage Collections"), 0,          ZTX("Organize images into collections"),            m_manage_coll, 0 );
-   MENUENT(mTools,   ZTX("Move Collections"), 0,            ZTX("Convert for a new top directory"),             m_move_coll, 0 );
-   MENUENT(mTools,   ZTX("Slide Show"), 0,                  ZTX("Start a slide show"),                          m_slideshow, 0 );
-   MENUENT(mTools,   ZTX("Batch Convert"), 0,               ZTX("Rename/convert/resize/move multiple files"),   m_batch_convert, 0 );
-   MENUENT(mTools,   ZTX("Batch Upright"), 0,               ZTX("Upright multiple files rotated 90º"),          m_batch_upright, 0 );
-   MENUENT(mTools,   ZTX("Batch RAW (DCraw)"), 0,           ZTX("Convert camera RAW files using DCraw"),        m_batch_dcraw, 0 );
-   MENUENT(mTools,   ZTX("Batch RAW (Raw Therapee)"), 0,    ZTX("Convert camera RAW files using Raw Therapee"), m_batch_rawtherapee, 0 );
-   MENUENT(mTools,   ZTX("Brightness Distribution"), 0,     ZTX("Show a brightness distribution graph"),        m_show_brdist, 0 );
-   MENUENT(mTools,   ZTX("Grid Lines"), 0,                  ZTX("Show or revise grid lines"),                   m_gridlines, 0 );
-   MENUENT(mTools,   ZTX("Show RGB"), 0,                    ZTX("Show RGB colors at mouse click"),              m_show_RGB, 0 );
-   MENUENT(mTools,   ZTX("Dark/Bright Pixels"), 0,          ZTX("Highlight darkest and brightest pixels"),      m_darkbrite, 0 );
-   MENUENT(mTools,   ZTX("Monitor Color"), 0,               ZTX("Chart to adjust monitor color"),               m_moncheck, 0 );
-   MENUENT(mTools,   ZTX("Monitor Gamma"), 0,               ZTX("Chart to adjust monitor gamma"),               m_mongamma, 0 );
-   MENUENT(mTools,   ZTX("Change Language"), 0,             ZTX("Change the GUI language"),                     m_lang, 0 );
-   MENUENT(mTools,   ZTX("Missing Translations"), 0,        ZTX("Report missing translations"),                 m_untranslated, 0 );
-   MENUENT(mTools,   ZTX("Menu and Launcher"), 0,           ZTX("Create a Gnome menu and launcher"),            m_menu_launcher, 0 );
-   MENUENT(mTools,   ZTX("Burn Images to CD/DVD"), 0,       ZTX("Burn selected image files to CD or DVD"),      m_burn, 0 );
-   MENUENT(mTools,   ZTX("Resources"), 0,                   ZTX("Memory and CPU (to terminal/logfile)"),        m_resources, 0 );
-///MENUENT(mTools,   ZTX("zappcrash test"), 0,                  "deliberate zappcrash",                         m_zappcrash, 0 );
+   MENUENT(mTools,   ZTX("Index Image Files"), 0,              ZTX("Index new files and make thumbnails"),           m_index, 0 );
+   MENUENT(mTools,   ZTX("User Settings"), 0,                  ZTX("Change user preferences"),                       m_settings, 0 );
+   MENUENT(mTools,   ZTX("Keyboard Shortcuts"), 0,             ZTX("Change Keyboard Shortcut Keys"),                 m_KBshortcuts, 0 );
+   MENUENT(mTools,   ZTX("Manage Collections"), 0,             ZTX("Organize images into collections"),              m_manage_coll, 0 );
+   MENUENT(mTools,   ZTX("Slide Show"), 0,                     ZTX("Start a slide show"),                            m_slideshow, 0 );
+   MENUENT(mTools,   ZTX("Batch Convert"), 0,                  ZTX("Rename/convert/resize/move multiple files"),     m_batch_convert, 0 );
+   MENUENT(mTools,   ZTX("Batch Upright"), 0,                  ZTX("Upright multiple files rotated 90º"),            m_batch_upright, 0 );
+   MENUENT(mTools,   ZTX("Batch RAW (DCraw)"), 0,              ZTX("Convert camera RAW files using DCraw"),          m_batch_dcraw, 0 );
+   MENUENT(mTools,   ZTX("Batch RAW (Raw Therapee)"), 0,       ZTX("Convert camera RAW files using Raw Therapee"),   m_batch_rawtherapee, 0 );
+   MENUENT(mTools,   ZTX("Show Brightness Distribution"), 0,   ZTX("Show a brightness distribution graph"),          m_show_brdist, 0 );
+   MENUENT(mTools,   ZTX("Grid Lines"), 0,                     ZTX("Show or revise grid lines"),                     m_gridlines, 0 );
+   MENUENT(mTools,   ZTX("Line Color"), 0,                     ZTX("Change color of foreground lines"),              m_fg_color, 0 );
+   MENUENT(mTools,   ZTX("Show RGB"), 0,                       ZTX("Show RGB colors at mouse click"),                m_show_RGB, 0 );
+   MENUENT(mTools,   ZTX("Dark/Bright Pixels"), 0,             ZTX("Highlight darkest and brightest pixels"),        m_darkbrite, 0 );
+   MENUENT(mTools,   ZTX("Find Duplicate Images"), 0,          ZTX("Search all image files and report duplicates"),  m_duplicates, 0 );
+   MENUENT(mTools,   ZTX("Monitor Color"), 0,                  ZTX("Chart to adjust monitor color"),                 m_moncheck, 0 );
+   MENUENT(mTools,   ZTX("Monitor Gamma"), 0,                  ZTX("Chart to adjust monitor gamma"),                 m_mongamma, 0 );
+   MENUENT(mTools,   ZTX("Change Language"), 0,                ZTX("Change the GUI language"),                       m_lang, 0 );
+   MENUENT(mTools,   ZTX("Missing Translations"), 0,           ZTX("Report missing translations"),                   m_untranslated, 0 );
+   MENUENT(mTools,   ZTX("Menu and Launcher"), 0,              ZTX("Create a Gnome menu and launcher"),              m_menu_launcher, 0 );
+   MENUENT(mTools,   ZTX("Burn Images to CD/DVD"), 0,          ZTX("Burn selected image files to CD or DVD"),        m_burn, 0 );
+   MENUENT(mTools,   ZTX("Resources"), 0,                      ZTX("Memory and CPU (to terminal/logfile)"),          m_resources, 0 );
+///MENUENT(mTools,   ZTX("zappcrash test"), 0,                     "deliberate zappcrash",                           m_zappcrash, 0 );
 
-   MENUENT(mMeta,    ZTX("Edit Metadata"), 0,               ZTX("Edit image tags/caption/rating ..."),      m_edit_metadata, 0 );
-   MENUENT(mMeta,    ZTX("Batch Add/Remove Tags"), 0,       ZTX("Add/remove tags for multiple images"),     m_batchTags, 0 );
    MENUENT(mMeta,    ZTX("View Metadata (short)"), 0,       ZTX("List a few key metadata items"),           m_meta_view_short, 0 );
    MENUENT(mMeta,    ZTX("View Metadata (long)"), 0,        ZTX("List all metadata items"),                 m_meta_view_long, 0 );
    MENUENT(mMeta,    ZTX("View Captions and Comments"), 0,  ZTX("List captions and comments only"),         m_meta_view_capcomm, 0 );
+   MENUENT(mMeta,    ZTX("Show Captions on Image"), 0,      ZTX("(Toggle) show captions and comments"),     m_captions, 0 );
+   MENUENT(mMeta,    ZTX("Edit Metadata"), 0,               ZTX("Edit image tags/caption/rating ..."),      m_edit_metadata, 0 );
    MENUENT(mMeta,    ZTX("Edit Any Metadata"), 0,           ZTX("Edit any image metadata"),                 m_meta_edit_any, 0 );
    MENUENT(mMeta,    ZTX("Delete Metadata"), 0,             ZTX("Remove all metadata from an image"),       m_meta_delete, 0 );
-   MENUENT(mMeta,    ZTX("Show Captions on Image"), 0,      ZTX("(Toggle) show captions and comments"),     m_captions, 0 );
+   MENUENT(mMeta,    ZTX("Batch Add/Remove Tags"), 0,       ZTX("Add/remove tags for multiple images"),     m_batchTags, 0 );
    MENUENT(mMeta,    ZTX("Download Geolocations"), 0,       ZTX("Download initial geolocation database"),   m_download_geolocs, 0 );
 ///MENUENT(mMeta,        "World Map Test", 0,                   "Test world map coordinates conversion",    m_worldmap_test, 0 );
    MENUENT(mMeta,    ZTX("Edit Geotags"), 0,                ZTX("Edit image location and geotags"),         m_edit_geotags, 0 );
@@ -271,60 +271,59 @@ void build_widgets()
    MENUENT(mMeta,    ZTX("Images by Map Location"), 0,      ZTX("Find images by clicking a world map"),     m_geotag_worldmap, 0 );
    MENUENT(mMeta,    ZTX("Search Images"), 0,               ZTX("Find images meeting select criteria"),     m_search_images, 0 );
 
-   MENUENT(mArea,    ZTX("Select"), 0,    ZTX("Select object or area for editing"),             m_select, 0 );
-   MENUENT(mArea,    ZTX("Show"), 0,      ZTX("Show (outline) existing area"),                  m_select_show, 0 );
-   MENUENT(mArea,    ZTX("Hide"), 0,      ZTX("Hide existing area"),                            m_select_hide, 0 );
-   MENUENT(mArea,    ZTX("Enable"), 0,    ZTX("Enable area for editing"),                       m_select_enable, 0 );
-   MENUENT(mArea,    ZTX("Disable"), 0,   ZTX("Disable area for editing"),                      m_select_disable, 0 );
-   MENUENT(mArea,    ZTX("Invert"), 0,    ZTX("Reverse existing area"),                         m_select_invert, 0 );
-   MENUENT(mArea,    ZTX("Unselect"), 0,  ZTX("Erase existing area"),                           m_select_unselect, 0 );
-   MENUENT(mArea,    ZTX("Copy"), 0,      ZTX("Copy an area for later pasting"),                m_select_copy, 0 );
-   MENUENT(mArea,    ZTX("Paste"), 0,     ZTX("Paste an area into the current image"),          m_select_paste, 0 );
-   MENUENT(mArea,    ZTX("Open"), 0,      ZTX("Open a file with a saved area"),                 m_select_open, 0 );
-   MENUENT(mArea,    ZTX("Save"), 0,      ZTX("Save an area to a file"),                        m_select_save, 0 );
-   MENUENT(mArea,    ZTX("Save PNG"), 0,  ZTX("Save an area to a PNG file with transparency"),  m_select_save_png, 0 );
+   MENUENT(mArea,    ZTX("Select"), 0,          ZTX("Select object or area for editing"),                m_select, 0 );
+   MENUENT(mArea,    ZTX("Show"), 0,            ZTX("Show (outline) existing area"),                     m_select_show, 0 );
+   MENUENT(mArea,    ZTX("Hide"), 0,            ZTX("Hide existing area"),                               m_select_hide, 0 );
+   MENUENT(mArea,    ZTX("Enable"), 0,          ZTX("Enable area for editing"),                          m_select_enable, 0 );
+   MENUENT(mArea,    ZTX("Disable"), 0,         ZTX("Disable area for editing"),                         m_select_disable, 0 );
+   MENUENT(mArea,    ZTX("Invert"), 0,          ZTX("Reverse existing area"),                            m_select_invert, 0 );
+   MENUENT(mArea,    ZTX("Unselect"), 0,        ZTX("Erase existing area"),                              m_select_unselect, 0 );
+   MENUENT(mArea,    ZTX("Area Color"), 0,      ZTX("Change color of area outlines"),                    m_fg_color, 0 );
+   MENUENT(mArea,    ZTX("Copy"), 0,            ZTX("Copy an area for later pasting"),                   m_select_copy, 0 );
+   MENUENT(mArea,    ZTX("Paste"), 0,           ZTX("Paste an area into the current image"),             m_select_paste, 0 );
+   MENUENT(mArea,    ZTX("Open"), 0,            ZTX("Open a file with a saved area"),                    m_select_open, 0 );
+   MENUENT(mArea,    ZTX("Save"), 0,            ZTX("Save an area to a file"),                           m_select_save, 0 );
+   MENUENT(mArea,    ZTX("Save PNG"), 0,        ZTX("Save an area to a PNG file with transparency"),     m_select_save_png, 0 );
 
-   MENUENT(mEdit,    ZTX("Rotate 90º"), 0,               ZTX("Rotate 90 degrees"),                          m_rotate90, 0 );
    MENUENT(mEdit,    ZTX("Trim/Rotate"), 0,              ZTX("Trim/Crop margins and/or Rotate"),            m_trimrotate, 0 );
+   MENUENT(mEdit,    ZTX("Rotate 90º"), 0,               ZTX("Rotate 90 degrees"),                          m_rotate90, 0 );
    MENUENT(mEdit,    ZTX("Auto-Trim"), 0,                ZTX("Remove margins from warp, panorama, etc."),   m_autotrim, 0 );
-   MENUENT(mEdit,    ZTX("Resize"), 0,                   ZTX("Change pixel dimensions"),                    m_resize, 0 );
-   MENUENT(mEdit,    ZTX("Flip"), 0,                     ZTX("Mirror image horizontally or vertically"),    m_flip, 0 );
-   MENUENT(mEdit,    ZTX("Add Text"), 0,                 ZTX("Write text on image"),                        m_write_text, 0 );
-   MENUENT(mEdit,    ZTX("Add Lines"), 0,                ZTX("Write lines or arrows on image"),             m_write_line, 0 );
    MENUENT(mEdit,    ZTX("Voodoo Enhance"), 0,           ZTX("Fast auto enhance that may work OK"),         m_voodoo, 0 );
    MENUENT(mEdit,    ZTX("Retouch Combo"), 0,            ZTX("Adjust brightness, contrast, color"),         m_combo, 0 );
    MENUENT(mEdit,    ZTX("Tone Mapping"), 0,             ZTX("Add local contrast, enhance details"),        m_tonemap, 0 );
    MENUENT(mEdit,    ZTX("Brightness Distribution"), 0,  ZTX("Adjust brightness distribution"),             m_adjust_brdist, 0 );
+   MENUENT(mEdit,    ZTX("Resize"), 0,                   ZTX("Change pixel dimensions"),                    m_resize, 0 );
+   MENUENT(mEdit,    ZTX("Flip"), 0,                     ZTX("Mirror image horizontally or vertically"),    m_flip, 0 );
+   MENUENT(mEdit,    ZTX("Add Text"), 0,                 ZTX("Write text on image"),                        m_write_text, 0 );
+   MENUENT(mEdit,    ZTX("Add Lines"), 0,                ZTX("Write lines or arrows on image"),             m_write_line, 0 );
    MENUENT(mEdit,    ZTX("Brightness Ramp"), 0,          ZTX("Fix brightness uniformity across image"),     m_brightramp, 0 );
    MENUENT(mEdit,    ZTX("Paint Edits"), 0,              ZTX("Paint edit function gradually with mouse"),   m_paint_edits, 0 );
    MENUENT(mEdit,    ZTX("Leverage Edits"), 0,           ZTX("Leverage edits by brightness or color"),      m_lever_edits, 0 );
 
-   MENUENT(mRep,  ZTX("Sharpen"), 0,            ZTX("Make the image look sharper"),                   m_sharpen, 0 );
-   MENUENT(mRep,  ZTX("Blur"), 0,               ZTX("Make the image look fuzzy"),                     m_blur, 0 );
-   MENUENT(mRep,  ZTX("Reduce Noise"), 0,       ZTX("Filter noise from low-light photos"),            m_denoise, 0 );
-   MENUENT(mRep,  ZTX("Smart Erase"), 0,        ZTX("Remove unwanted objects"),                       m_smart_erase, 0 );
-   MENUENT(mRep,  ZTX("Red Eyes"), 0,           ZTX("Fix red-eyes from electronic flash"),            m_redeye, 0 );
-   MENUENT(mRep,  ZTX("Paint/Clone"), 0,        ZTX("Paint image pixels using the mouse"),            m_paint_clone, 0 );
-   MENUENT(mRep,  ZTX("Remove Dust"), 0,        ZTX("Remove dust spots from scanned slides"),         m_dust, 0 );
-   MENUENT(mRep,  ZTX("Anti-alias"), 0,         ZTX("Smoothen edges with jaggies"),                   m_antialias, 0 );
-   MENUENT(mRep,  ZTX("Fix Color Fringes"), 0,  ZTX("Reduce Chromatic Abberation"),                   m_chromatic, 0 );
-   MENUENT(mRep,  ZTX("Fix Stuck Pixels"), 0,   ZTX("Erase known hot and dark pixels"),               m_stuckpix, 0 );
-
-   MENUENT(mColor,   ZTX("Line Color"), 0,         ZTX("Change color of area borders, overlay lines"),   m_fg_color, 0 );
-   MENUENT(mColor,   ZTX("Shift Colors"), 0,       ZTX("Shift/convert colors into other colors"),        m_shift_colors, 0 );
-   MENUENT(mColor,   ZTX("Color Mode"), 0,         ZTX("Make BW/color, negative/positive, sepia"),       m_colormode, 0 );
-   MENUENT(mColor,   ZTX("Color Profile"), 0,      ZTX("Convert to another color profile"),              m_colorprof, 0 );
-   MENUENT(mColor,   ZTX("Match Colors"), 0,       ZTX("Match colors on one image with another"),        m_match_color, 0 );
-   MENUENT(mColor,   ZTX("Revise RGB"), 0,         ZTX("Adjust color in selected image areas"),          m_revise_RGB, 0 );
-   MENUENT(mColor,       "CMYK", 0,                ZTX("Adjust color using CMYK or RGB values"),         m_CMYK, 0 );
+   MENUENT(mRep,  ZTX("Sharpen"), 0,               ZTX("Make the image look sharper"),                   m_sharpen, 0 );
+   MENUENT(mRep,  ZTX("Blur"), 0,                  ZTX("Make the image look fuzzy"),                     m_blur, 0 );
+   MENUENT(mRep,  ZTX("Reduce Noise"), 0,          ZTX("Filter noise from low-light photos"),            m_denoise, 0 );
+   MENUENT(mRep,  ZTX("Smart Erase"), 0,           ZTX("Remove unwanted objects"),                       m_smart_erase, 0 );
+   MENUENT(mRep,  ZTX("Red Eyes"), 0,              ZTX("Fix red-eyes from electronic flash"),            m_redeye, 0 );
+   MENUENT(mRep,  ZTX("Paint/Clone Pixels"), 0,    ZTX("Paint image pixels using the mouse"),            m_paint_clone, 0 );
+   MENUENT(mRep,  ZTX("Remove Dust"), 0,           ZTX("Remove dust spots from scanned slides"),         m_dust, 0 );
+   MENUENT(mRep,  ZTX("Anti-alias"), 0,            ZTX("Smoothen edges with jaggies"),                   m_antialias, 0 );
+   MENUENT(mRep,  ZTX("Fix Color Fringes"), 0,     ZTX("Reduce Chromatic Abberation"),                   m_chromatic, 0 );
+   MENUENT(mRep,  ZTX("Fix Stuck Pixels"), 0,      ZTX("Erase known hot and dark pixels"),               m_stuckpix, 0 );
+   MENUENT(mRep,  ZTX("Shift Colors"), 0,          ZTX("Shift/convert colors into other colors"),        m_shift_colors, 0 );
+   MENUENT(mRep,  ZTX("Color Mode"), 0,            ZTX("Make BW/color, negative/positive, sepia"),       m_colormode, 0 );
+   MENUENT(mRep,  ZTX("Color Profile"), 0,         ZTX("Convert to another color profile"),              m_colorprof, 0 );
+   MENUENT(mRep,  ZTX("Match Colors"), 0,          ZTX("Match colors on one image with another"),        m_match_color, 0 );
+   MENUENT(mRep,  ZTX("Revise RGB"), 0,            ZTX("Adjust color in selected image areas"),          m_revise_RGB, 0 );
+   MENUENT(mRep,      "CMYK", 0,                   ZTX("Adjust color using CMYK or RGB values"),         m_CMYK, 0 );
 
    MENUENT(mBend,    ZTX("Unbend"), 0,             ZTX("Remove curvature, esp. panoramas"),         m_unbend, 0 );
    MENUENT(mBend,    ZTX("Fix Perspective"), 0,    ZTX("Straighten objects seen from an angle"),    m_perspective, 0 );
-   MENUENT(mBend,    ZTX("Flatten Book Page"), 0,  ZTX("Flatten a photographed book page"),         m_flatbook, 0 );
    MENUENT(mBend,    ZTX("Warp area"), 0,          ZTX("Distort image areas using the mouse"),      m_warp_area, 0 );
    MENUENT(mBend,    ZTX("Warp curved"), 0,        ZTX("Distort the whole image using the mouse"),  m_warp_curved, 0 );
    MENUENT(mBend,    ZTX("Warp linear"), 0,        ZTX("Distort the whole image using the mouse"),  m_warp_linear, 0 );
    MENUENT(mBend,    ZTX("Warp affine"), 0,        ZTX("Distort the whole image using the mouse"),  m_warp_affine, 0 );
+   MENUENT(mBend,    ZTX("Flatten Book Page"), 0,  ZTX("Flatten a photographed book page"),         m_flatbook, 0 );
 
    MENUENT(mEff,  ZTX("Color Depth"), 0,     ZTX("Reduce color depth (posterize)"),                   m_colordep, 0 );
    MENUENT(mEff,  ZTX("Sketch"), 0,          ZTX("Convert to pencil sketch"),                         m_sketch, 0 );
@@ -340,6 +339,7 @@ void build_widgets()
    MENUENT(mEff,  ZTX("Pattern"), 0,         ZTX("Tile image with a repeating pattern"),              m_pattern, 0 );
    MENUENT(mEff,  ZTX("Mosaic"), 0,          ZTX("Create a mosaic with tiles made from all images"),  m_mosaic, 0);
    MENUENT(mEff,  ZTX("Custom Kernel"), 0,   ZTX("Process an image using a custom kernel"),           m_anykernel, 0);
+   MENUENT(mEff,  ZTX("Make Waves"), 0,      ZTX("Warp an image with a wave pattern"),                m_waves, 0);
 
    MENUENT(mComb,    ZTX("High Dynamic Range"), 0,  ZTX("Combine bright/dark images for better detail"),    m_HDR, 0 );
    MENUENT(mComb,    ZTX("High Depth of Field"), 0, ZTX("Combine near/far focus images for deeper focus"),  m_HDF, 0 );
@@ -366,9 +366,6 @@ void build_widgets()
    
    //  G view menu
 
-   mToolsG = create_popmenu();                                             //  v.14.07
-   cchar * toolsG_tip = ZTX("Batch functions, Combine functions");
-
    MENUENT(0,  ZTX("Image"),        "viewF.png",      imagefile_tip,                               m_viewmode, "F" );
    MENUENT(0,  ZTX("World Map"),    "viewW.png",      worldmap_tip,                                m_viewmode, "W" );
    MENUENT(0,  ZTX("Sync.G"),       "sync.G.png",     sync_G_tip,                                  navi::menufuncx, 0 );
@@ -384,11 +381,20 @@ void build_widgets()
    MENUENT(0,  ZTX("Row↑"),         "up.png",        ZTX("previous row"),                         navi::menufuncx, 0 );
    MENUENT(0,  ZTX("Row↓"),         "down.png",      ZTX("next row"),                             navi::menufuncx, 0 );
    MENUENT(0,  ZTX("Scroll"),       "scroll.png",     ZTX("slow scroll"),                          navi::menufuncx, 0 );
+
+   mToolsG = create_popmenu();                                             //  v.14.07  v.14.09
+   cchar * toolsG_tip = ZTX("Batch functions, Combine functions");
+
    MENUENT(0,  ZTX("Tools"),        "tools.png",      toolsG_tip,               (cbFunc *) popup_menu,  (cchar *) mToolsG);
 
    MENUENT(mToolsG,  ZTX("Batch Convert"), 0,               ZTX("Rename/convert/resize/move multiple files"),        m_batch_convert, 0 );
    MENUENT(mToolsG,  ZTX("Batch RAW (DCraw)"), 0,           ZTX("Convert camera RAW files using DCraw"),             m_batch_dcraw, 0 );
    MENUENT(mToolsG,  ZTX("Batch RAW (Raw Therapee)"), 0,    ZTX("Convert camera RAW files using Raw Therapee"),      m_batch_rawtherapee, 0 );
+   MENUENT(mToolsG,  ZTX("Batch Add Geotags"), 0,           ZTX("Add geotags to multiple images"),                   m_batch_add_geotags, 0 );
+   MENUENT(mToolsG,  ZTX("Images by Location/Date"), 0,     ZTX("Find all images for a location [date]"),            m_geotag_groups, 0 );
+   MENUENT(mToolsG,  ZTX("Images by Map Location"), 0,      ZTX("Find images by clicking a world map"),              m_geotag_worldmap, 0 );
+   MENUENT(mToolsG,  ZTX("Search Images"), 0,               ZTX("Find images meeting select criteria"),              m_search_images, 0 );
+   MENUENT(mToolsG,  ZTX("Find Duplicate Images"), 0,       ZTX("Search all image files and report duplicates"),     m_duplicates, 0 );
    MENUENT(mToolsG,  ZTX("High Dynamic Range"), 0,          ZTX("Combine bright/dark images for better detail"),     m_HDR, 0 );
    MENUENT(mToolsG,  ZTX("High Depth of Field"), 0,         ZTX("Combine near/far focus images for deeper focus"),   m_HDF, 0 );
    MENUENT(mToolsG,  ZTX("Stack / Paint"), 0,               ZTX("Combine images to erase passing people, etc."),     m_STP, 0 );
@@ -411,6 +417,7 @@ void build_widgets()
    Vmenu *Gvm = Vmenu_new(Gmenu);
    Vmenu *Wvm = Vmenu_new(Wmenu);
    Vmenu *Xvm;
+   int   iz = iconsize;
 
    for (me = 0; me < Nmenus; me++)
    {
@@ -427,23 +434,23 @@ void build_widgets()
       else {                                                               //  top menu
          if (strEqu(menu_style,"icons")) {
             if (menutab[me].icon)
-               Vmenu_add(Xvm, 0, menutab[me].icon, 32, 32, menutab[me].desc, 
+               Vmenu_add(Xvm, 0, menutab[me].icon,iz,iz,menutab[me].desc, 
                                  menutab[me].func, menutab[me].arg);
             else
                Vmenu_add(Xvm, menutab[me].menu, 0, 0, 0, menutab[me].desc, 
                               menutab[me].func, menutab[me].arg);
-            }
-         if (strEqu(menu_style,"both")) 
-            Vmenu_add(Xvm, menutab[me].menu, menutab[me].icon, 32, 32, 
+         }
+         else  /* both */                                                  //  bugfix                             v.14.10.1
+            Vmenu_add(Xvm, menutab[me].menu, menutab[me].icon,iz,iz, 
                            menutab[me].desc, menutab[me].func, menutab[me].arg);
       }
    }
    
    //  add plugin menu items to plugins menu
 
-   char        plugfile[200], buff[200], *pp;
-   FILE        *fid;
-   struct stat stbuff;
+   char     plugfile[200], buff[200], *pp;
+   FILE     *fid;
+   STATB    stbuff;
 
    snprintf(plugfile,200,"%s/plugins",get_zuserdir());                     //  plugins file
 
@@ -486,6 +493,7 @@ void build_widgets()
    //  do setups for right-click popup menus
 
    cchar    *menupopimage = ZTX("Popup Image");                            //  v.14.03
+   cchar    *menupopimageadd = ZTX("Popup Image (add)");                   //  v.14.09
    cchar    *menumetadata1 = ZTX("View Metadata");
    cchar    *menumetadata2 = ZTX("Edit Metadata");
    cchar    *menurename = ZTX("Rename");
@@ -534,6 +542,7 @@ void build_widgets()
 
    popmenu_thumb = create_popmenu();                                       //  gallery thumbnail
    add_popmenu_item(popmenu_thumb,menupopimage,popup_menufunc,"popimage");
+   add_popmenu_item(popmenu_thumb,menupopimageadd,popup_menufunc,"popimageadd");
    add_popmenu_item(popmenu_thumb,menumetadata1,popup_menufunc,"view metadata");
    add_popmenu_item(popmenu_thumb,menurename,popup_menufunc,"rename");
    add_popmenu_item(popmenu_thumb,menurotate90,popup_menufunc,"rotate 90º thumb");
@@ -581,8 +590,8 @@ void m_viewmode(GtkWidget *, cchar *fgw)
       set_mwin_title(); 
 
       Cstate = &Fstate;                                                    //  set drawing area
-      Cdraw = Fdraw;
-      gdkwin = gtk_widget_get_window(Fdraw);                               //  GDK window
+      Cdrawin = Fdrawin;
+      gdkwin = gtk_widget_get_window(Fdrawin);                             //  GDK window
    }
 
    if (*fgw == 'G')                                                        //  set G view mode for thumbnail gallery
@@ -591,29 +600,29 @@ void m_viewmode(GtkWidget *, cchar *fgw)
       gtk_widget_hide(Whbox);
       gtk_widget_show_all(Ghbox);
 
-      Cstate = 0;                                                          //  no F/W image drawing area
-      Cdraw = 0;
-      gdkwin = 0;
-
       static int ftf = 1;                                                  //  required to avoid lack of scroll for the
       if (ftf) zmainloop();                                                //    first time gallery is painted (GTK bug?)
       ftf = 0;
 
-      if (curr_file) gallery(curr_file,"paint",curr_file_posn);            //  set gallery position at curr. file
-      else gallery(0,"paint",-1);
+      Cstate = 0;                                                          //  no F/W image drawing area
+      Cdrawin = 0;
+      gdkwin = 0;
+      
+      if (curr_file) gallery(curr_file,"paint");                           //  set gallery posn. at curr. file    v.14.10
+      else gallery(0,"paint",-1);                                          //  else leave unchanged
    }
 
    if (*fgw == 'W')                                                        //  set W view mode for world map
    {
-      if (! init_geolocs()) return;                                        //  initialize geolocations
+      if (! load_worldmap()) return;                                       //  initialize world map and geolocs
 
       gtk_widget_hide(Fhbox);
       gtk_widget_hide(Ghbox);
       gtk_widget_show_all(Whbox);
    
       Cstate = &Wstate;                                                    //  set drawing area
-      Cdraw = Wdraw;
-      gdkwin = gtk_widget_get_window(Wdraw);                               //  GDK window
+      Cdrawin = Wdrawin;
+      gdkwin = gtk_widget_get_window(Wdrawin);                             //  GDK window
 
       m_geotag_worldmap(0,0);                                              //  activate clickable world map
 
@@ -629,7 +638,8 @@ void m_viewmode(GtkWidget *, cchar *fgw)
 
 void popup_menufunc(GtkWidget *, cchar *menu)                              //  v.12.12
 {
-   if (strEqu(menu,"popimage")) popimage();                                //  funcs for main and gallery windows
+   if (strEqu(menu,"popimage")) popimage(0);                               //  funcs for main and gallery windows
+   if (strEqu(menu,"popimageadd")) popimage(1);
    if (strEqu(menu,"view metadata")) meta_view(1);
    if (strEqu(menu,"edit metadata")) m_edit_metadata(0,0);
    if (strEqu(menu,"rename")) m_rename(0,0);                               //  these funcs use clicked_file if defined,
@@ -691,7 +701,7 @@ void gallery_Lclick_func(int Nth)
 
 //  gallery thumbnail mouse right-click popup menu
 
-void gallery_Rclick_popup(int Nth)                                         //  v.13.07
+void gallery_Rclick_popup(int Nth)
 {
    int      ftyp;
    
