@@ -20,7 +20,7 @@
 
 ***************************************************************************/
 
-//     zfuncs.h   version  v.5.9
+//     zfuncs.h   version  v.6.0
 
 #include <sys/sysinfo.h> 
 #include <sys/time.h>
@@ -49,16 +49,17 @@
 
 #define  int8   char                                                       //  number types
 #define  int16  short
-#define  int32  long
-#define  int64  long long
+#define  int32  int
+#define  int64  long long                                                  //  long long is always 64 bits
 #define  uint8   unsigned char
 #define  uint16  unsigned short
-#define  uint32  unsigned long
+#define  uint32  unsigned int
 #define  uint64  unsigned long long
 #define  uchar  unsigned char
 #define  cchar  const char
 
 #define  wstrerror(err) strerror(WEXITSTATUS(err))                         //  get text status for child process
+#define  STATB  struct stat
 
 #define  mutex_tp       pthread_mutex_t                                    //  abbreviations
 #define  mutex_init     pthread_mutex_init
@@ -106,6 +107,8 @@ double jobtime();                                                          //
 void compact_time(const time_t fileDT, char *compactDT);                   //  time_t date/time to yyyymmddhhmmss
 int  parseprocfile(cchar *pfile, cchar *pname, double *value, ...);        //  get data from /proc file
 int  parseprocrec(char *prec, int field, double *value, ...);              //  get data from /proc file record
+void coretemps(int &lotemp, int &hitemp);                                  //  get low and high cpu core temps    v.5.9
+int  disktemp(char *disk);                                                 //  get disk temp, e.g. "/dev/sda"     v.5.9
 void zsleep(double dsecs);                                                 //  sleep specified seconds
 int global_lock(cchar *lockfile);                                          //  obtain exclusive lock, multi-process
 int global_unlock(int fd, cchar *lockfile);                                //  release the lock
@@ -205,14 +208,15 @@ cchar * SearchWildIgnoreCase(cchar *wpath, int &flag);                     //  w
 //  search and sort functions =============================================
 
 int bsearch(int seekint, int nn, int list[]);                              //  binary search sorted list[nn]
-int bsearch(char *seekrec, char *allrecs, int recl, int nrecs);            //  binary search sorted records
-int bsearch(char *seekrec, char **allrecs, int N, int nrecs);              //  binary search of sorted pointers to recs
+int bsearch(cchar *seekrec, cchar *allrecs, int recl, int nrecs);          //  binary search sorted records
+int bsearch(cchar *seekrec, cchar **allrecs, int N, int nrecs);            //  binary search of sorted pointers to recs
 
 typedef int HeapSortUcomp(cchar *rec1, cchar *rec2);                       //  return -1/0/+1 if rec1 </=/> rec2
 void HeapSort(int vv[], int nn);                                           //  Heap Sort - integer
 void HeapSort(float vv[], int nn);                                         //  Heap Sort - float
 void HeapSort(double vv[], int nn);                                        //  Heap Sort - double
 void HeapSort(char *vv[], int nn);                                         //  Heap Sort - char *, ascending order
+void HeapSort(char *vv1[], char *vv2[], int nn);                           //  Heap Sort - parallel char *, ascending order
 void HeapSort(char *vv[], int nn, HeapSortUcomp);                          //  Heap Sort - char *, user-defined order 
 void HeapSort(char *recs, int RL, int NR, HeapSortUcomp);                  //  Heap Sort - records, user-defined order
 
@@ -298,6 +302,8 @@ cchar * ZTX_missing(int &ftf);                                             //  g
 
 void zmainloop(int skip = 0);                                              //  do main loop, process menu events
 void zthreadcrash();                                                       //  crash if thread is not main() thread
+void get_hardware_info(GtkWidget *);                                       //  get hardware info (display, screen, mouse)
+int  move_pointer(GtkWidget *, int px, int py);                            //  move the mouse pointer to px, py
 
 //  text window print and read utilities
 
@@ -319,10 +325,6 @@ void textwidget_set_clickfunc(GtkWidget *widget, clickfunc_t clickfunc);   //  (
 char * textwidget_get_line(GtkWidget *widget, int line, int hilite);       //  get entire line at clicked position
 char * textwidget_get_word(char *line, int pos, cchar *dlims, char &end);  //  get delimited word at clicked position
 
-//  get the screen and mouse for a given widget
-
-int get_mouse_device(GtkWidget *, GdkScreen **screen, GdkDevice **mouse);  //  return pointers to screen and mouse
-
 //  functions to simplify building menus, tool bars, status bars
 
 #define G_SIGNAL(window,event,func,arg) \
@@ -424,7 +426,8 @@ struct zdialog  {
       int         saveinputs;                      //  save and recall user inputs each use
       int         stopKB;                          //  flag, next KB event will be ignored
       GtkWidget   *parent;                         //  parent window or null
-      GtkWidget   *compbutt[zdmaxbutts];           //  dialog completion buttons
+      cchar       *compbutton[zdmaxbutts];         //  dialog completion button labels                      v.5.9
+      GtkWidget   *compwidget[zdmaxbutts];         //  dialog completion button widgets
       zwidget     widget[zdmaxwidgets];            //  dialog widgets (EOF = type = 0)
 };
 
@@ -441,6 +444,7 @@ int zdialog_add_widget(zdialog *zd,                                        //  a
 
 int zdialog_valid(zdialog *zd);                                            //  return 1/0 if zdialog valid/invalid
 GtkWidget * zdialog_widget(zdialog *zd, cchar *name);                      //  GTK widget from zdialog widget name
+int zdialog_add_ttip(zdialog *zd, cchar *wname, cchar *ttip);              //  add popup tool tip to a widget
 int zdialog_resize(zdialog *zd, int width, int height);                    //  set size > widget sizes
 int zdialog_put_data(zdialog *zd, cchar *name, cchar *data);               //  put data in widget (entry, spin ...)
 cchar * zdialog_get_data(zdialog *zd, cchar *name);                        //  get widget data
@@ -496,11 +500,10 @@ int zmessageYN(GtkWidget *parent, cchar *format, ... );
 zdialog * zmessage_post(GtkWidget *parent, int secs, cchar *format, ...);           //  show message, timeout or cancel
 char * zdialog_text(GtkWidget *parent, cchar * title, cchar * initext);             //  get short text input from user
 int zdialog_choose(cchar *title, GtkWidget *parent, cchar *format, ...);            //  show message, return choice 
-void poptext_mouse(cchar *text, GdkDevice *, int dx, int dy, float s1, float s2);   //  show popup text at mouse posn
+void poptext_mouse(cchar *text, int dx, int dy, float s1, float s2);                //  show popup text at mouse posn
 void poptext_window(cchar *text, GtkWindow *, int mx, int my, float s1, float s2);  //  show popup text at window posn
 int  poptext_killnow();                                                             //  kill current popup window
-int  popup_image(cchar *imagefile, GtkWindow *parent, int size);                    //  show image in a small popup window
-int  move_pointer(GtkWidget *, int px, int py);                                     //  move the mouse pointer to px, py
+int  popup_image(cchar *imagefile, GtkWindow *parent, int Fnewin, int size);        //  popup window with image
 
 //  file chooser dialogs for one file or multiple files
 
